keepers

package
v5.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 31, 2025 License: Apache-2.0 Imports: 104 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewAvailableStaticPrecompiles

func NewAvailableStaticPrecompiles(
	stakingKeeper stakingkeeper.Keeper,
	distributionKeeper distributionkeeper.Keeper,
	bankKeeper bankkeeper.Keeper,
	erc20Keeper erc20Keeper.Keeper,
	transferKeeper transferkeeper.Keeper,
	clientKeeper clientkeeper.Keeper,
	connectionKeeper connectionkeeper.Keeper,
	channelKeeper *channelkeeper.Keeper,
	evmKeeper *evmkeeper.Keeper,
	govKeeper govkeeper.Keeper,
	slashingKeeper slashingkeeper.Keeper,
	evidenceKeeper evidencekeeper.Keeper,
	wasmdKeeper wasmkeeper.Keeper,
	oracleKeeper oraclekeeper.Keeper,
	codec codec.Codec,
	opts ...Option,
) map[common.Address]vm.PrecompiledContract

NewAvailableStaticPrecompiles returns the list of all available static precompiled contracts from EVM.

NOTE: this should only be used during initialization of the Keeper.

Types

type AppKeepers

type AppKeepers struct {

	// keepers
	AccountKeeper      authkeeper.AccountKeeper
	BankKeeper         bankkeeper.Keeper
	StakingKeeper      *stakingkeeper.Keeper
	SlashingKeeper     slashingkeeper.Keeper
	DistrKeeper        distrkeeper.Keeper
	GovKeeper          *govkeeper.Keeper
	UpgradeKeeper      *upgradekeeper.Keeper
	ParamsKeeper       paramskeeper.Keeper //nolint:staticcheck
	WasmKeeper         wasmkeeper.Keeper
	TokenFactoryKeeper tokenfactorykeeper.Keeper
	RewardsKeeper      rewardskeeper.Keeper
	// IBC Keeper must be a pointer in the app, so we can SetRouter on it correctly
	IBCKeeper             *ibckeeper.Keeper
	ICAHostKeeper         icahostkeeper.Keeper
	ICAControllerKeeper   icacontrollerkeeper.Keeper
	EvidenceKeeper        evidencekeeper.Keeper
	TransferKeeper        ibctransferkeeper.Keeper
	FeeGrantKeeper        feegrantkeeper.Keeper
	AuthzKeeper           authzkeeper.Keeper
	ConsensusParamsKeeper consensusparamkeeper.Keeper
	OracleKeeper          oraclekeeper.Keeper
	FeeAbstractionKeeper  feeabstractionkeeper.Keeper

	PFMRouterKeeper *pfmrouterkeeper.Keeper
	RatelimitKeeper ratelimitkeeper.Keeper

	// Modules
	ICAModule       ica.AppModule
	TransferModule  transfer.AppModule
	PFMRouterModule pfmrouter.AppModule
	RateLimitModule ratelimit.AppModule

	// EVM keepers
	FeeMarketKeeper feemarketkeeper.Keeper
	EVMKeeper       *evmkeeper.Keeper
	Erc20Keeper     erc20keeper.Keeper
	// contains filtered or unexported fields
}

func NewAppKeeper

func NewAppKeeper(
	appCodec codec.Codec,
	bApp *baseapp.BaseApp,
	legacyAmino *codec.LegacyAmino,
	maccPerms map[string][]string,
	modAccAddrs map[string]bool,
	blockedAddress map[string]bool,
	skipUpgradeHeights map[int64]bool,
	homePath string,
	logger log.Logger,
	appOpts servertypes.AppOptions,
	wasmOpts []wasmkeeper.Option,
) AppKeepers

func (*AppKeepers) GenerateKeys

func (appKeepers *AppKeepers) GenerateKeys()

func (*AppKeepers) GetKVStoreKey

func (appKeepers *AppKeepers) GetKVStoreKey() map[string]*storetypes.KVStoreKey

func (*AppKeepers) GetKey

func (appKeepers *AppKeepers) GetKey(storeKey string) *storetypes.KVStoreKey

GetKey returns the KVStoreKey for the provided store key.

NOTE: This is solely to be used for testing purposes.

func (*AppKeepers) GetMemKey

func (appKeepers *AppKeepers) GetMemKey(storeKey string) *storetypes.MemoryStoreKey

GetMemKey returns the MemStoreKey for the provided mem key.

NOTE: This is solely used for testing purposes.

func (*AppKeepers) GetMemoryStoreKey

func (appKeepers *AppKeepers) GetMemoryStoreKey() map[string]*storetypes.MemoryStoreKey

func (*AppKeepers) GetSubspace

func (appKeepers *AppKeepers) GetSubspace(moduleName string) paramstypes.Subspace

GetSubspace returns a param subspace for a given module name.

func (*AppKeepers) GetTKey

func (appKeepers *AppKeepers) GetTKey(storeKey string) *storetypes.TransientStoreKey

GetTKey returns the TransientStoreKey for the provided store key.

NOTE: This is solely to be used for testing purposes.

func (*AppKeepers) GetTransientStoreKey

func (appKeepers *AppKeepers) GetTransientStoreKey() map[string]*storetypes.TransientStoreKey

type DefaultFeemarketDenomResolver

type DefaultFeemarketDenomResolver struct{}

func (*DefaultFeemarketDenomResolver) ConvertToDenom

func (r *DefaultFeemarketDenomResolver) ConvertToDenom(_ sdk.Context, coin sdk.DecCoin, denom string) (sdk.DecCoin, error)

func (*DefaultFeemarketDenomResolver) ExtraDenoms

func (r *DefaultFeemarketDenomResolver) ExtraDenoms(_ sdk.Context) ([]string, error)

type Option

type Option func(opts *Optionals)

Option returns a funcion for the corresponding needed coded

func WithAddressCodec

func WithAddressCodec(codec address.Codec) Option

WithAddressCodec returns the function to access the with address codec

func WithConsensusAddrCodec

func WithConsensusAddrCodec(codec address.Codec) Option

WithConsensusAddrCodec returns the function to access the with consensus address codec

func WithValidatorAddrCodec

func WithValidatorAddrCodec(codec address.Codec) Option

WithValidatorAddrCodec returns the function to access the with validator address codec

type Optionals

type Optionals struct {
	AddressCodec       address.Codec // used by gov/staking
	ValidatorAddrCodec address.Codec // used by slashing
	ConsensusAddrCodec address.Codec // used by slashing
}

Optionals define some optional params that can be applied to _some_ precompiles. Extend this struct, add a sane default to defaultOptionals, and an Option function to provide users with a non-breaking way to provide custom args to certain precompiles.

Jump to