e2e

package
v5.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 31, 2025 License: Apache-2.0 Imports: 73 Imported by: 0

Documentation

Overview

package e2e defines an integration testing suite used for full end-to-end testing functionality.

The file e2e_suite_test.go defines the testing suite and contains the core bootstrapping logic that creates a testing environment via Docker containers. A testing network is created dynamically and contains multiple Docker containers:

1. Two independent Kiichain networks 3. A hermes relayer connecting the two Kiichain networks over IBC

The file e2e_test.go contains the actual end-to-end integration tests that utilize the testing suite.

Index

Constants

This section is empty.

Variables

var (
	EVMHdPath    = "m/44'/60'/0'/0/0"
	EthSecp256k1 = "eth_secp256k1"
)

Wallets variables

Functions

func AccAddress

func AccAddress() sdk.AccAddress

AccAddress returns a sample account address

func Address

func Address() string

Address returns a sample string account address

func EVMTransaction

func EVMTransaction(
	client *ethclient.Client,
	privateKey *ecdsa.PrivateKey,
	fromAddress common.Address,
	toAddress common.Address,
	amount *big.Int,
	contractBinary []byte,
) (geth.Receipt, error)

EVMTransaction builds up an evm_sendTransaction and returns its receipt

func HDPath

func HDPath(index int) string

HDPath generates an HD path based on the wallet index

func PubKey

func PubKey() crypto.PubKey

PubKey returns a sample account PubKey

Types

type EVMAccount

type EVMAccount struct {
	// contains filtered or unexported fields
}

EVMAccount stores an address and a key used for EVM interaction

Directories

Path Synopsis

Jump to