Documentation
¶
Overview ¶
package e2e defines an integration testing suite used for full end-to-end testing functionality.
The file e2e_suite_test.go defines the testing suite and contains the core bootstrapping logic that creates a testing environment via Docker containers. A testing network is created dynamically and contains multiple Docker containers:
1. Two independent Kiichain networks 3. A hermes relayer connecting the two Kiichain networks over IBC
The file e2e_test.go contains the actual end-to-end integration tests that utilize the testing suite.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( EVMHdPath = "m/44'/60'/0'/0/0" EthSecp256k1 = "eth_secp256k1" )
Wallets variables
Functions ¶
Types ¶
type EVMAccount ¶
type EVMAccount struct {
// contains filtered or unexported fields
}
EVMAccount stores an address and a key used for EVM interaction
Source Files
¶
Click to show internal directories.
Click to hide internal directories.